import { readFileSync } from 'fs';
import path from 'path';
import { describe, expect, test } from 'vitest';
import { getSizesFromSourceAndSourcemap } from './get-sizes-from-source-and-sourcemap.js';
describe('parse-source-map', () => {
    test('parseSourceMap', async () => {
        const src = readFileSync(path.join(__dirname, '../fixtures/gatsby-app.js'));
        const map = readFileSync(path.join(__dirname, '../fixtures/gatsby-app.js.map'));
        const results = getSizesFromSourceAndSourcemap({ src, map });
        expect(results).toEqual({
            '(webpack)/buildin/global.js': 128,
            './.cache/_this_is_virtual_fs_path_/$virtual/async-requires.js': 9925,
            './.cache/api-runner-browser-plugins.js': 2516,
            './.cache/api-runner-browser.js': 662,
            './.cache/create-react-context.js': 56,
            './.cache/emitter.js': 267,
            './.cache/ensure-resources.js': 1156,
            './.cache/find-path.js': 785,
            './.cache/gatsby-browser-entry.js': 1882,
            './.cache/loader.js': 6746,
            './.cache/navigation.js': 5148,
            './.cache/normalize-page-path.js': 87,
            './.cache/page-renderer.js': 652,
            './.cache/prefetch.js': 860,
            './.cache/production-app.js': 2605,
            './.cache/public-page-renderer-prod.js': 503,
            './.cache/public-page-renderer.js': 42,
            './.cache/react-lifecycles-compat.js': 30,
            './.cache/register-service-worker.js': 1206,
            './.cache/route-announcer-props.js': 195,
            './.cache/strip-prefix.js': 96,
            './gatsby-browser.js': 1099,
            './node_modules/@babel/runtime/helpers/arrayLikeToArray.js': 112,
            './node_modules/@babel/runtime/helpers/arrayWithHoles.js': 49,
            './node_modules/@babel/runtime/helpers/arrayWithoutHoles.js': 67,
            './node_modules/@babel/runtime/helpers/assertThisInitialized.js': 129,
            './node_modules/@babel/runtime/helpers/esm/arrayLikeToArray.js': 106,
            './node_modules/@babel/runtime/helpers/esm/arrayWithoutHoles.js': 51,
            './node_modules/@babel/runtime/helpers/esm/defineProperty.js': 120,
            './node_modules/@babel/runtime/helpers/esm/extends.js': 207,
            './node_modules/@babel/runtime/helpers/esm/inheritsLoose.js': 95,
            './node_modules/@babel/runtime/helpers/esm/iterableToArray.js': 90,
            './node_modules/@babel/runtime/helpers/esm/nonIterableSpread.js': 31,
            './node_modules/@babel/runtime/helpers/esm/toConsumableArray.js': 361,
            './node_modules/@babel/runtime/helpers/esm/unsupportedIterableToArray.js': 353,
            './node_modules/@babel/runtime/helpers/extends.js': 228,
            './node_modules/@babel/runtime/helpers/inheritsLoose.js': 101,
            './node_modules/@babel/runtime/helpers/interopRequireDefault.js': 56,
            './node_modules/@babel/runtime/helpers/interopRequireWildcard.js': 548,
            './node_modules/@babel/runtime/helpers/iterableToArray.js': 100,
            './node_modules/@babel/runtime/helpers/iterableToArrayLimit.js': 305,
            './node_modules/@babel/runtime/helpers/nonIterableRest.js': 41,
            './node_modules/@babel/runtime/helpers/nonIterableSpread.js': 41,
            './node_modules/@babel/runtime/helpers/objectWithoutPropertiesLoose.js': 140,
            './node_modules/@babel/runtime/helpers/slicedToArray.js': 105,
            './node_modules/@babel/runtime/helpers/toConsumableArray.js': 99,
            './node_modules/@babel/runtime/helpers/typeof.js': 261,
            './node_modules/@babel/runtime/helpers/unsupportedIterableToArray.js': 307,
            './node_modules/@emotion/cache/dist/cache.browser.esm.js': 1024,
            './node_modules/@emotion/core/dist/core.browser.esm.js': 2511,
            './node_modules/@emotion/core/dist/emotion-element-57a3a7a3.browser.esm.js': 1010,
            './node_modules/@emotion/css/dist/css.browser.esm.js': 122,
            './node_modules/@emotion/hash/dist/hash.browser.esm.js': 551,
            './node_modules/@emotion/memoize/dist/memoize.browser.esm.js': 80,
            './node_modules/@emotion/serialize/dist/serialize.browser.esm.js': 1825,
            './node_modules/@emotion/sheet/dist/sheet.browser.esm.js': 1124,
            './node_modules/@emotion/stylis/dist/stylis.browser.esm.js': 8201,
            './node_modules/@emotion/unitless/dist/unitless.browser.esm.js': 639,
            './node_modules/@emotion/utils/dist/utils.browser.esm.js': 379,
            './node_modules/@mikaelkristiansson/domready/ready.js': 431,
            './node_modules/@reach/router/es/index.js': 10301,
            './node_modules/@reach/router/es/lib/history.js': 2243,
            './node_modules/@reach/router/es/lib/utils.js': 2454,
            './node_modules/core-js/internals/a-function.js': 101,
            './node_modules/core-js/internals/an-object.js': 101,
            './node_modules/core-js/internals/array-includes.js': 271,
            './node_modules/core-js/internals/array-method-is-strict.js': 112,
            './node_modules/core-js/internals/array-method-uses-to-length.js': 348,
            './node_modules/core-js/internals/array-reduce.js': 362,
            './node_modules/core-js/internals/classof-raw.js': 66,
            './node_modules/core-js/internals/copy-constructor-properties.js': 152,
            './node_modules/core-js/internals/create-non-enumerable-property.js': 122,
            './node_modules/core-js/internals/create-property-descriptor.js': 91,
            './node_modules/core-js/internals/descriptors.js': 106,
            './node_modules/core-js/internals/document-create-element.js': 118,
            './node_modules/core-js/internals/engine-is-node.js': 53,
            './node_modules/core-js/internals/engine-user-agent.js': 54,
            './node_modules/core-js/internals/engine-v8-version.js': 196,
            './node_modules/core-js/internals/enum-bug-keys.js': 109,
            './node_modules/core-js/internals/export.js': 396,
            './node_modules/core-js/internals/fails.js': 54,
            './node_modules/core-js/internals/get-built-in.js': 172,
            './node_modules/core-js/internals/global.js': 255,
            './node_modules/core-js/internals/has.js': 64,
            './node_modules/core-js/internals/hidden-keys.js': 10,
            './node_modules/core-js/internals/ie8-dom-define.js': 142,
            './node_modules/core-js/internals/indexed-object.js': 166,
            './node_modules/core-js/internals/inspect-source.js': 132,
            './node_modules/core-js/internals/internal-state.js': 658,
            './node_modules/core-js/internals/is-forced.js': 245,
            './node_modules/core-js/internals/is-object.js': 75,
            './node_modules/core-js/internals/is-pure.js': 11,
            './node_modules/core-js/internals/native-weak-map.js': 93,
            './node_modules/core-js/internals/object-define-property.js': 256,
            './node_modules/core-js/internals/object-get-own-property-descriptor.js': 230,
            './node_modules/core-js/internals/object-get-own-property-names.js': 112,
            './node_modules/core-js/internals/object-get-own-property-symbols.js': 11,
            './node_modules/core-js/internals/object-keys-internal.js': 204,
            './node_modules/core-js/internals/object-property-is-enumerable.js': 145,
            './node_modules/core-js/internals/own-keys.js': 144,
            './node_modules/core-js/internals/path.js': 26,
            './node_modules/core-js/internals/redefine.js': 524,
            './node_modules/core-js/internals/require-object-coercible.js': 83,
            './node_modules/core-js/internals/set-global.js': 88,
            './node_modules/core-js/internals/shared-key.js': 83,
            './node_modules/core-js/internals/shared-store.js': 92,
            './node_modules/core-js/internals/shared.js': 161,
            './node_modules/core-js/internals/to-absolute-index.js': 97,
            './node_modules/core-js/internals/to-indexed-object.js': 61,
            './node_modules/core-js/internals/to-integer.js': 82,
            './node_modules/core-js/internals/to-length.js': 85,
            './node_modules/core-js/internals/to-object.js': 54,
            './node_modules/core-js/internals/to-primitive.js': 274,
            './node_modules/core-js/internals/uid.js': 108,
            './node_modules/core-js/modules/es.array.reduce.js': 263,
            './node_modules/decode-uri-component/index.js': 874,
            './node_modules/escape-string-regexp/index.js': 132,
            './node_modules/gatsby-link/index.js': 4309,
            './node_modules/gatsby-link/parse-path.js': 235,
            './node_modules/gatsby-plugin-catch-links/catch-links.js': 2349,
            './node_modules/gatsby-plugin-catch-links/gatsby-browser.js': 143,
            './node_modules/gatsby-plugin-google-analytics/gatsby-browser.js': 437,
            './node_modules/gatsby-plugin-google-tagmanager/gatsby-browser.js': 206,
            './node_modules/gatsby-plugin-manifest/gatsby-browser.js': 30,
            './node_modules/gatsby-plugin-manifest/get-manifest-pathname.js': 212,
            './node_modules/gatsby-plugin-nprogress/gatsby-browser.js': 2155,
            './node_modules/gatsby-plugin-sentry/gatsby-browser.js': 99,
            './node_modules/gatsby-plugin-twitter/gatsby-browser.js': 920,
            './node_modules/gatsby-react-router-scroll/index.js': 221,
            './node_modules/gatsby-react-router-scroll/scroll-container.js': 962,
            './node_modules/gatsby-react-router-scroll/scroll-handler.js': 1719,
            './node_modules/gatsby-react-router-scroll/session-storage.js': 727,
            './node_modules/gatsby-react-router-scroll/use-scroll-restoration.js': 341,
            './node_modules/gatsby-remark-autolink-headers/gatsby-browser.js': 717,
            './node_modules/gatsby-remark-images/constants.js': 357,
            './node_modules/gatsby-remark-images/gatsby-browser.js': 680,
            './node_modules/gatsby-source-wordpress-experimental/gatsby-browser.js': 0,
            './node_modules/gatsby/dist/internal-plugins/bundle-optimisations/polyfills/object-assign.js': 17,
            './node_modules/invariant/browser.js': 342,
            './node_modules/mitt/dist/mitt.es.js': 260,
            './node_modules/nprogress/nprogress.js': 3965,
            './node_modules/query-string/index.js': 5527,
            './node_modules/query-string/node_modules/strict-uri-encode/index.js': 129,
            './node_modules/shallow-compare/es/index.js': 1726,
            './node_modules/split-on-first/index.js': 217,
            './node_modules/uuid/index.js': 56,
            './node_modules/uuid/lib/bytesToUuid.js': 291,
            './node_modules/uuid/lib/rng-browser.js': 423,
            './node_modules/uuid/v1.js': 818,
            './node_modules/uuid/v4.js': 251,
            './src/utils/analytics/hooks/useTracker.ts': 2471,
            './src/utils/analytics/types.ts': 1084,
            './src/utils/analytics/utils/index.ts': 300,
            './src/utils/analytics/utils/legacy-helpers.js': 1088
        });
    }, { timeout: 10 * 1000 });
});
//# sourceMappingURL=get-sizes-from-source-and-sourcemap.test.js.map